TextSource class

Indicates where the text encoding was decoded from.

The text is the substring of str from begin to end.

Implementers

Properties

begin → int
Offset into the source string where the data starts.
final
decodedText → String
The text that was decoded to produce the data.
no setter
end → int
Offset into the source string where the data ends.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
str → String
Source the data was decoded from.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited